plus1 = "<font size=\"+1\">"

shinyServer(function(input, output, session) {

    output$checkGraph <- renderText({
        if(input$whichgraph=="base") return("")
        if(is.element("ggplot2", installed.packages()[,1])) {
            library(ggplot2)
            return("")
        }    
        else return(paste(red,"<h4>Warning: ggplot2 graphics package not found, go back to base graphics</h4>"))
        NULL       
    }) 
         
  data <- reactive({
      x <- sort(runif(input$n))
      y <- input$intercept+input$slope*x+rnorm(input$n,0,input$sd)
      data.frame(x=x,y=y)
  })
  
  
  output$plot1 <- renderPlot({
      if(input$whichgraph=="base") {
          plot(data(),pch=20)
          abline(lm(y~x, data=data()),lwd=2,col="red")
      }    
      else {
        if(is.element("ggplot2", installed.packages()[,1])) {
            dta <- data()
            co <- coef(lm(y~x, data=data()))
            ggplot(dta,aes(x,y))+
            geom_point()+
            geom_abline(intercept=co[1],slope=co[2],size=1.2,colour="blue")
        }
      }                  
  })  
    
  output$text1 <- renderText({ 
      fit <- lm(y~x, data=data())
      cf <- round(coef(fit),2)
      r2 <- round(summary(fit)$r.squared*100,1)
      sgn=ifelse(sign(cf[2])==1,"+","-")
      line <- paste("<h4>Least Squares Regression Equation:",HTML("y&#770;")," = ",cf[1],sgn,abs(cf[2]),"x</h4>",collapse="")
      
      cf <- round(c(input$intercept,input$slope),2)
      sgn=ifelse(sign(cf[2])==1,"+","-")
      line[2] <- paste("<h4>True Line: y = ",cf[1],sgn,abs(cf[2]),"x</h4>",collapse="")
      if(sum(cf)==0) 
          line[2] <- "<h4>True Line: y = 0</h4>"
      else {
            if(cf[1]==0)  line[2] <- paste("<h4>True Line: y = ",cf[2],"x</h4>",collapse="")
            if(cf[2]==0)  line[2] <- paste("<h4>True Line: y = ",cf[1],"</h4>",collapse="")
      }            
      line[3] <- paste("<h4>R<sup>2</sup> = ",r2,"%</h4>",collapse="")
      line
   })
     
   output$appinfo <- renderText({ 
      HTML("<br>&nbsp;<br>&nbsp;<br>&nbsp;<br>
      <a target=\"_blank\" href=\"http://academic.uprm.edu/wrolke/myapps1.htm#lsr\"><h4>What to do</h4></a><br>
      <h6>Written by: Dr. Wolfgang Rolke<br>Created: 11/20/2014</h6>")
      
  })     
     output$explainText <- renderText({ 
         "<h5>Move the sliders around to see different cases of true lines and  least squares regression equations
         <br>Some interesting things to check:
         <br>How does changing the sample size effect things?
         <br>How does changing the residual standard deviation change things?</h5>" 
     })

})

